# The Mostpopular News Kompas.com
This package will get the Mostpopular News From Kompas.com |
Kompas.com is a web portal that contains online news and articles on Indonesia.
Kompas.com is one of the most popular news sites in Indonesia.

## How it work?
This package will scrape from [kompas](https://www.kompas.com/) to get the Mostpopular News From Kompas.com.

It package will use BeautifulSoup4 and Request,
to produce output in the form of JSON that is ready to be used in web or mobile applications

## How To Use!

    import beritaterpopuler

    if __name__ == '__main__':
        print("main application")
        result = mostpopuler_news.data_extraction()
        mostpopuler_news.data_show(result)

### Author

Deni Rahmawan




